/*
  ==============================================================================

    This file contains the basic framework code for a JUCE plugin editor.

  ==============================================================================
*/

#include "PluginProcessor.h"
#include "PluginEditor.h"

//==============================================================================
NewProjectAudioProcessorEditor::NewProjectAudioProcessorEditor (NewProjectAudioProcessor& p)
    : AudioProcessorEditor (&p), audioProcessor (p)
{
    MenuBarModel::setMacMainMenu(this, nullptr);

    commandManager.registerAllCommandsForTarget(this);
    commandManager.setFirstCommandTarget(this);

    addAndMakeVisible(ed);

    // Make sure that before the constructor has finished, you've set the
    // editor's size to whatever you need it to be.
    setSize (400, 300);
}

NewProjectAudioProcessorEditor::~NewProjectAudioProcessorEditor()
{
    if(juce::JUCEApplicationBase::isStandaloneApp())
    {
        MenuBarModel::setMacMainMenu(nullptr);
    }
}

//==============================================================================
void NewProjectAudioProcessorEditor::paint (juce::Graphics& g)
{
    // (Our component is opaque, so we must completely fill the background with a solid colour)
    g.fillAll (getLookAndFeel().findColour (juce::ResizableWindow::backgroundColourId));
}

void NewProjectAudioProcessorEditor::resized()
{
    // This is generally where you'll want to lay out the positions of any
    // subcomponents in your editor..
    ed.setBounds(getLocalBounds().reduced(50));
}

juce::ApplicationCommandTarget* NewProjectAudioProcessorEditor::getNextCommandTarget()
{
    return nullptr;
}

void NewProjectAudioProcessorEditor::getAllCommands (juce::Array<juce::CommandID>& commands)
{
    const juce::Array<juce::CommandID> ids{ 1, 2 };
    commands.addArray(ids);
}

void NewProjectAudioProcessorEditor::getCommandInfo (juce::CommandID commandID, juce::ApplicationCommandInfo& result)
{
    switch(commandID)
    {
        case 1:
            result.setInfo("Yadda", "Yadda", "Yadda", 0);
            result.addDefaultKeypress(juce::KeyPress::rightKey, juce::ModifierKeys::noModifiers);
            result.setActive(true);
            break;
        case 2:
            result.setInfo("Woop", "Woop", "Woop", 0);
            result.addDefaultKeypress('.', juce::ModifierKeys::noModifiers);
            result.setActive(true);
            break;
        default:
            jassertfalse;
    }
}

bool NewProjectAudioProcessorEditor::perform (const juce::ApplicationCommandTarget::InvocationInfo& info)
{
    switch(info.commandID)
    {
        case 1:
            DBG("Right key!");
            return true;
        case 2:
            DBG(". key!");
            return true;
        default:
            return false;
    }
}

juce::StringArray NewProjectAudioProcessorEditor::getMenuBarNames()
{
    return { "Blah" };
}

juce::PopupMenu NewProjectAudioProcessorEditor::getMenuForIndex (int topLevelMenuIndex, const juce::String& menuName)
{
    juce::PopupMenu menu;
    switch(topLevelMenuIndex)
    {
        case 0:
            menu.addCommandItem(&commandManager, 1);
            menu.addCommandItem(&commandManager, 2);
            break;
        default:
            jassertfalse;
            break;
    }
    return menu;
}

void NewProjectAudioProcessorEditor::menuItemSelected (int menuItemID, int topLevelMenuIndex)
{

}

